fnss.topologies.parsers.parse_rocketfuel_isp_latency — FNSS 0.7.0 documentation

# fnss.topologies.parsers.parse_rocketfuel_isp_latency

`parse_rocketfuel_isp_latency`(latencies_path, weights_path=None)

  Parse a network topology from RocketFuel ISP topology file (latency.intra) with inferred link latencies and optionally annotate the topology with inferred weights (weights.infra).

  The ASes provided by the RocketFuel dataset are the following:

  ASN | Name | Span | Region | Nodes | Lrgst conn. comp.
  --- | --- | --- | --- | --- | ---
  1221 1239 1755 3257 3967 6461 | Telstra (Australia) Sprintlink (US) EBONE (Europe) Tiscali (Europe) Exodus (US) Abovenet (US) | world world world world world world | AUS US Europe Europe US US | 108 315 87 161 79 141 | 104 315 87 161 79 138

  Parameters: | latencies_path : str The path of the file containing the RocketFuel latencies file. It should have extension .intra weights_path : str, optional The path of the file containing the RocketFuel weights file. It should have extension .intra
  Returns: | topology : DirectedTopology The object containing the parsed topology.

  Notes

  The returned topology is directed. It can be converted using the DirectedTopology.to_undirected() method if an undirected topology is desired.

  Each node of the returned graph has the following attributes:
    - name: string
    - location: string
  Each edge of the returned graph has the following attributes:
    - delay : int
    - wdights : float (only if a weights file was specified)

  Examples

      >>> import fnss
      >>> topology = fnss.parse_rocketfuel_isp_latency('1221.latencies.intra')